function GaussConv

%end point
T=0.5;

%initial value
y0=pi/4;

%number of steps
Nh=2.^(4:8);

%number of Newton iterations
nNewton=1:3;

%right hand side
f=@(x) exp(x)*sin(x);

%Jacobian of right hand side
Df=@(x) exp(x)*(sin(x)+cos(x));

%reference solution 
opts=odeset('RelTol',1e-12,'AbsTol',1e-12);
[tref,yref]=ode45(@(t,x) f(x),[0 T],y0,opts);

%loop over number of iterations
for ii=1:length(Nh)
    
    %Solution with one Newton iteration
    y1=impGauss(y0,f,Df,T,Nh(ii),nNewton(1));
    
    %solution with 2 and 3 Newton iterations
    y2=impGauss(y0,f,Df,T,Nh(ii),nNewton(2));
    y3=impGauss(y0,f,Df,T,Nh(ii),nNewton(3));
    
    %error with 1, 2 and 3 iterations
    err1(ii)=abs(y1-yref(end));
    err2(ii)=abs(y2-yref(end));
    err3(ii)=abs(y3-yref(end));
end

%plot
figure;
loglog(Nh,err1,'r*-');
hold on;
loglog(Nh,err2,'b*-');
loglog(Nh,err3,'m*-');
legend('nNewton=1','nNewton=2','nNewton=3');
xlabel('Number of steps')
ylabel('Absolute error')

print -depsc GaussConv

%Estimate convergence rate
p=polyfit(log(Nh),log(err1),1);
fprintf('nNewton = 1 -> Rate = %3.4f\n',p(1))
p=polyfit(log(Nh),log(err2),1);
fprintf('nNewton = 2 -> Rate = %3.4f\n',p(1))
p=polyfit(log(Nh),log(err3),1);
fprintf('nNewton = 3 -> Rate = %3.4f\n',p(1))